## What is this repository for? ##
* Defining overlays to openCV's VideoCapture class for adding new features
    (simulating different fps, automatic resize of images, ...)
* Providing a displayer handy for non-consuming interactions with the video
